cb_key_stroke package — cb_key_stroke documentation

# cb_key_stroke package

key_stroke - The python loop key pressed interupt module

key_stroke is a small module to quit/terminate a loop of a console app by simply pressing a key. The beauty is that this module is running on Linux, Öpfel-Rechnern as well Fenster operated computers.

Have fun while using the key_stroke module! Thomas

## Submodules

- cb_key_stroke.cb_key_stroke module
  - `CBKeyStroke`
    - `CBKeyStroke.getch()`
    - `CBKeyStroke.kbhit()`
  - `CBKeyStrokeBase`
    - `CBKeyStrokeBase.check()`
    - `CBKeyStrokeBase.getch()`
    - `CBKeyStrokeBase.kbhit()`